@@ -24,6 +24,6 @@ def test_brace_complex():
     )
 
 if __name__ == '__main__':
-    from base_test import main
+    from .base_test import main
     main('-vv')
 
