@@ -7,6 +7,6 @@ def test_syntax_error():
     Formatter.format_string('a = '),
 
 if __name__ == '__main__':
-    from base_test import main
+    from .base_test import main
     main('-vv')
 
