@@ -63,6 +63,6 @@ def test_slice():
     )
 
 if __name__ == '__main__':
-    from base_test import main
+    from .base_test import main
     main('-vv')
 
