@@ -35,6 +35,6 @@ def test_paren_complex():
     )
 
 if __name__ == '__main__':
-    from base_test import main
+    from .base_test import main
     main('-vv')
 
