@@ -1,7 +1,9 @@
+from __future__ import print_function
+
 from formatter2 import Formatter
 from nose import tools
 import sys
-from StringIO import StringIO
+from io import StringIO
 
 
 def test_stdin():
@@ -9,7 +11,7 @@ def test_stdin():
     formatter = Formatter()
     sys.stdin, stdin = fh, sys.stdin
 
-    print >>fh, 'test = 123'
+    print(u'test = 123', file=fh)
 
     fh.seek(0)
     formatter('-'),
@@ -26,7 +28,10 @@ def test_stdin():
         open(filename, 'r').read(),
     )
 
+    sys.stdin = stdin
+
+
 if __name__ == '__main__':
-    from base_test import main
+    from .base_test import main
     main('-vv')
 
