@@ -53,6 +53,6 @@ def test_string_type():
     )
 
 if __name__ == '__main__':
-    from base_test import main
+    from .base_test import main
     main('-vv')
 
